@@ -56,6 +56,9 @@ ARGUMENT_RENAMES = {
     'stepfunctions.send-task-success.output': 'task-output',
     'clouddirectory.publish-schema.version': 'schema-version',
     'mturk.list-qualification-types.query': 'types-query',
+    'workdocs.create-notification-subscription.endpoint':
+        'notification-endpoint',
+    'workdocs.describe-users.query': 'user-query'
 }
 
 # Same format as ARGUMENT_RENAMES, but instead of renaming the arguments,
